@@ -4,7 +4,7 @@
 # Copyright (c) 2010 Benoît HERVIER
 # Licenced under GPLv3
 
-"""A simple Twitter client made with pyqt4"""
+'''A simple Twitter client made with pyqt4'''
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
@@ -21,21 +21,22 @@ import dbus
 import dbus.service
 import dbus.mainloop.qt
 import pickle
+from PIL import Image
 
-__version__ = '0.0.22'
+__version__ = '0.0.23'
 
+def write_report(error):
+    filename = os.path.join(CACHE_PATH,'crash_report')
+    output = open(filename, 'wb')
+    pickle.dump(error, output)
+    output.close()
+        
 #Here is the installation of the hook. Each time a untrapped/unmanaged exception will
 #happen my_excepthook will be called.
 def install_excepthook(app_name,app_version):
 
     APP_NAME = 'Khweeteur'
     APP_VERSION = __version__
-
-    def write_report(error):
-        filename = os.path.join(CACHE_PATH,'crash_report')
-        output = open(filename, 'wb')
-        pickle.dump(error, output)
-        output.close()
         
     def my_excepthook(exctype, value, tb):
         #traceback give us all the errors information message like the method, file line ... everything like
@@ -54,6 +55,7 @@ KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
 KHWEETEUR_TWITTER_CONSUMER_SECRET = 'lbKAvvBiyTlFsJfb755t3y1LVwB0RaoMoDwLD14VvU'
 KHWEETEUR_IDENTICA_CONSUMER_KEY = 'c7e86efd4cb951871200440ad1774413'
 KHWEETEUR_IDENTICA_CONSUMER_SECRET = '236fa46bf3f65fabdb1fd34d63c26d28'
+SCREENNAMEROLE = 20
 
 class KhweeteurDBus(dbus.service.Object):
     @dbus.service.method("net.khertan.khweeteur",
@@ -208,9 +210,16 @@ class KhweeteurWorker(QThread):
             cache = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url.replace('/','_')))
             if not(os.path.exists(cache)):
                 try:
-                    urlretrieve(status.user.profile_image_url, cache)
+                    urlretrieve(status.user.profile_image_url, cache)                    
+                    #print 'try to convert to png'
+                    im = Image.open(cache)
+                    im = im.resize((50,50))
+                    #transparency = im.info['transparency'] 
+                    #im.save(os.path.splitext(cache)[0]+'.png', 'PNG', transparency=transparency)
+                    im.save(os.path.splitext(cache)[0]+'.png', 'PNG')
+#                    print os.path.splitext(cache)[0]+'.png'
                 except StandardError,e:
-                    print e
+                    print 'DownloadProfileImage Error : ',e
         
     def refresh_search(self):
         downloadProfileImage = self.downloadProfileImage
@@ -235,6 +244,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except StandardError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
         try:
             identica_last_id = None
@@ -250,6 +262,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except StandardError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
 
         if len(mlist)>0:
@@ -360,12 +375,11 @@ class KhweetsModel(QAbstractListModel):
         self._new_counter = 0
         self.now = time.time()
         
-        self.display_screenname = False
-        self.display_timestamp = False
-        self.display_avatar = True
-
         self.keyword = keyword
 
+    # def flags(self, index):
+        # return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsUserCheckable | Qt.ItemIsEditable | Qt.ItemIsDragEnabled
+        
     def GetRelativeCreatedAt(self,timestamp):
         '''Get a human redable string representing the posting time
 
@@ -411,10 +425,11 @@ class KhweetsModel(QAbstractListModel):
         
     def addStatuses(self,listVariant):
         GetRelativeCreatedAt = self.GetRelativeCreatedAt
-        print 'Debug addstatuses count:',len(listVariant)
+        #print 'Debug addstatuses count:',len(listVariant)
         for _,variant in listVariant:
             try:
                 if all(item[1]!=variant.id for item in self._items):
+                    self.beginInsertRows(QModelIndex(), 0,1)  
                     if type(variant) != twitter.DirectMessage:
                         self._items.insert(0,
                             (variant.created_at_in_seconds,
@@ -427,8 +442,13 @@ class KhweetsModel(QAbstractListModel):
                         if variant.user.screen_name!=None:
                             try:
                                 if variant.user.profile_image_url[4]!=None:
-                                    pix = QPixmap(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))).scaled(50,50)
-                                    self._avatars[variant.user.profile_image_url] = QIcon(pix)
+                                    path = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))
+                                    if not path.endswith('.png'):
+                                        path = os.path.splitext(path)[0] + '.png'
+                                    pix = QPixmap(path) #.scaled(50,50)
+                                    if pix.isNull():
+                                        print path
+                                    self._avatars[variant.user.profile_image_url] = (pix)
                             except StandardError, err:
                                 print 'error on loading avatar :',err
                     else:
@@ -439,16 +459,16 @@ class KhweetsModel(QAbstractListModel):
                               variant.text,
                               None,
                               GetRelativeCreatedAt(variant.created_at_in_seconds),))
-                              
                     self._new_counter = self._new_counter + 1
                     self.now = time.time()
-                    
+                    self.endInsertRows()
             except StandardError, e:
                 print "We shouldn't got this error here :",e
 
         if len(listVariant):
             QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
             self.serialize()
+
             
     def getNewAndReset(self):
         counter = self._new_counter
@@ -457,8 +477,11 @@ class KhweetsModel(QAbstractListModel):
 
     def getNew(self):
         return self._new_counter
+    
+    def setData(self,index,variant,role):
+        return True
         
-    def setData(self,mlist):
+    def setTweets(self,mlist):
         try:
             if len(mlist)>0:
                 if type(mlist[0])==tuple:
@@ -466,13 +489,17 @@ class KhweetsModel(QAbstractListModel):
                         self._items = mlist
                         self._new_counter = 0
                         QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
+                        return True
                     else:
                         print 'Wrong cache format'
+                        write_report("%s Version %s\nOld cache format : %s\n" % ('Khweeteur', __version__, ''))
                         KhweeteurNotification().info('Old cache format. Reinit cache.')            
-        except:
+        except StandardError,err:
             KhweeteurNotification().info('Wrong cache format. Reinit cache.')
+            write_report("%s Version %s\nWrong cache format : %s\n" % ('Khweeteur', __version__, err))
             print 'Wrong cache format'
-
+        return False
+        
     def serialize(self):
         try:
             if self.keyword==None:
@@ -494,7 +521,7 @@ class KhweetsModel(QAbstractListModel):
                 filename = os.path.normcase(unicode(os.path.join(unicode(CACHE_PATH),unicode(self.keyword.replace('/','_'))+u'.cache'))).encode('UTF-8')          
             pkl_file = open(filename, 'rb')
             items = pickle.load(pkl_file)
-            self.setData(items)
+            self.setTweets(items)
             pkl_file.close()
         except StandardError,e:
             print 'unSerialize : ',e
@@ -516,8 +543,13 @@ class KhweetsModel(QAbstractListModel):
             for item in self._items:
                 try:
                     if item[4]!=None:
-                        pix = (QPixmap(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4].replace('/','_'))))).scaled(50,50)
-                        self._avatars[item[4]] = QIcon(pix)
+                        path = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4].replace('/','_')))
+                        if not path.endswith('.png'):
+                            path = os.path.splitext(path)[0]+'.png'
+                        pix = (QPixmap(path)) #.scaled(50,50)
+                        if pix.isNull():
+                            print path
+                        self._avatars[item[4]] = (pix)
                 except StandardError, err:
                     print 'error on loading avatar :',err 
             self._items.sort()
@@ -526,32 +558,118 @@ class KhweetsModel(QAbstractListModel):
 
     def data(self, index, role = Qt.DisplayRole):
         if role == Qt.DisplayRole:
-            status = self._items[index.row()][3]
-            if self.display_timestamp:
-                status = status +'\n'+ self._items[index.row()][5]     
-            if self.display_screenname:
-                status = self._items[index.row()][2]+ ' : ' + status            
-            return QVariant(status)
+            return QVariant(self._items[index.row()][3])
+        elif role == SCREENNAMEROLE:
+            return QVariant(self._items[index.row()][2])
+        elif role == Qt.ToolTipRole:
+            return self._items[index.row()][5]
         elif role == Qt.DecorationRole:            
-            if self.display_avatar:
-                try:
-                    return self._avatars[self._items[index.row()][4]]
-                except:
-                    return QVariant()
-            else:
+            try:
+                return self._avatars[self._items[index.row()][4]]
+            except:
                 return QVariant()
         else:
             return QVariant()
+     
+    def wantsUpdate(self):
+        QObject.emit(self, SIGNAL("layoutChanged()"))
+
+class CustomDelegate(QStyledItemDelegate):
+    '''Delegate to do custom draw of the items'''
+
+    def __init__(self, parent):
+        '''Initialization'''
+        QStyledItemDelegate.__init__(self, parent)
+        self.show_avatar = True
+        self.show_screenname = True
+        self.show_timestamp = True
+
+        self.tips_color = QColor('#7AB4F5')
+        self.bg_color = QColor('#333333')
+                
+        self.fm = None
+        
+        self.normFont = None
+        self.miniFont = None
+
+    def sizeHint (self, option, index):
+        '''Custom size calculation of our items'''
+        size = QStyledItemDelegate.sizeHint(self, option, index)
+        tweet = index.data(Qt.DisplayRole).toString()
+        #One time is enought sizeHint need to be fast
+        if self.fm == None:
+            self.fm = QFontMetrics(option.font)
+        height = self.fm.boundingRect(0,0,option.rect.width()-75,800, int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet).height()
+        return QSize(size.width(), height+25)
+        
+
+    def paint(self, painter, option, index):
+        '''Paint our tweet'''
+        self.fm = QFontMetrics(option.font)
+
+        model = index.model()
+        tweet = index.data(Qt.DisplayRole).toString()
+        
+        #Instantiate font only one time !
+        if self.normFont == None:
+            self.normFont = QFont(option.font)
+            self.miniFont = QFont(option.font)
+            self.miniFont.setPointSizeF(option.font.pointSizeF() * 0.80)            
+        
+        painter.save()
+        
+        # Draw alternate ?
+        if (index.row()%2)==0:
+            painter.fillRect(option.rect, self.bg_color)
+
+        # highlight selected items
+        if option.state & QStyle.State_Selected: 
+            painter.fillRect(option.rect, option.palette.highlight());
+                    
+        # Draw icon
+        if self.show_avatar:
+            icon = index.data(Qt.DecorationRole).toPyObject();
+            x1,y1,x2,y2 = option.rect.getCoords()
+            painter.drawPixmap(x1+2,y1+6,50,50,icon)
+                                                
+        # Draw tweet
+        new_rect = painter.drawText(option.rect.adjusted(int(self.show_avatar)*70,0,0,0),  int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet); 
+                
+        # Draw Timeline
+        if self.show_timestamp:
+            time = index.data(Qt.ToolTipRole).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.tips_color)
+            painter.drawText(option.rect.adjusted(70,0,-2,0),  int(Qt.AlignBottom) | int(Qt.AlignRight), time);
+
+        # Draw screenname
+        if self.show_screenname:
+            screenname = index.data(SCREENNAMEROLE).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.tips_color)
+            painter.drawText(option.rect.adjusted(70,0,-2,0),  int(Qt.AlignBottom) | int(Qt.AlignLeft), screenname);
+
+        painter.restore()
 
 class KhweetsView(QListView):
+    ''' Model View '''
     def __init__(self,parent=None):
         QListView.__init__(self,parent)
-        self.setIconSize(QSize(128, 128))
+        #self.setIconSize(QSize(128, 128))
+        #self.setStyleSheet('QListView { background-color: rgb(241, 245, 250); border: 0; }')
         self.setWordWrap(True)
-        self.setUniformItemSizes(True)
+        self.custom_delegate = CustomDelegate(self)
+        self.setItemDelegate(self.custom_delegate)
+        self.setEditTriggers(QAbstractItemView.SelectedClicked)
+        self.setSpacing(2)
+        self.setUniformItemSizes(False)
         self.setResizeMode(QListView.Adjust)
-        self.setViewMode(QListView.ListMode)
+        #self.setViewMode(QListView.ListMode)
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
+        #self.setWrapping(True)
+        #self.setFlow(QListView.TopToBottom)
+#        self.setAlternatingRowColors(True)  
 #        self.setAlternatingRowColors(True)
 
 
@@ -567,7 +685,7 @@ class KhweeteurAbout(QMainWindow):
         aboutScrollArea = QScrollArea(self)
         aboutScrollArea.setWidgetResizable(True)
         awidget = QWidget(aboutScrollArea)
-        awidget.setMinimumSize(480,700)
+        awidget.setMinimumSize(480,1000)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         scroller = aboutScrollArea.property("kineticScroller").toPyObject()
@@ -581,23 +699,46 @@ class KhweeteurAbout(QMainWindow):
         aboutIcon.resize(128,128)
         aboutLayout.addWidget(aboutIcon)
 
-        aboutLabel = QLabel('''<center><b>Khweeteur</b> %s
+        aboutLabel = QLabel('''<center><b>Khweeteur</b> %s                                   
                                    <br><br>A Simple twitter client with follower status, reply,
                                    <br>and direct message in a unified view
                                    <br><br>Licenced under GPLv3
                                    <br>By Beno&icirc;t HERVIER (Khertan)
-                                   <br><br><br><b>Site Web : </b>http://khertan.net/khweeteur
+                                   <br><br><b>Khweeteur try to be simple and fast identi.ca and twitter client,</b>
+                                   <br>your timeline, reply and direct message arer displayed in a unified view.
+                                   <br><br><b>To reply, retweet, open a url, follow/unfollow an account :</b>
+                                   <br>double click on a status and choose the action in the dialog which appear.
+                                   <br><br>To activate automatic update set a refresh interval different of zero.
+                                   <br><br>Use preferences from dialog to set your account with oauth,
+                                   <br>and to display or not timestamp, username or avatar.                                   
                                    <br><br><b>Thanks to :</b>
                                    <br>ddoodie on #pyqt                                   
                                    <br>xnt14 on #maemo
                                    <br>trebormints on twitter
+                                   <br>moubaildotcom on twitter
+                                   <br>teotwaki on twitter
                                    </center>''' % __version__)
         aboutLayout.addWidget(aboutLabel)
-
+        self.bugtracker_button = QPushButton('BugTracker')
+        self.bugtracker_button.clicked.connect(self.open_bugtracker)
+        self.website_button = QPushButton('Website')
+        self.website_button.clicked.connect(self.open_website)
+        awidget2 = QWidget()
+        buttonLayout = QHBoxLayout(awidget2)        
+        buttonLayout.addWidget(self.bugtracker_button)
+        buttonLayout.addWidget(self.website_button)
+        aboutLayout.addWidget(awidget2)
+        
         awidget.setLayout(aboutLayout)
         aboutScrollArea.setWidget(awidget)
         self.setCentralWidget(aboutScrollArea)
-        self.show()
+        self.show()        
+        
+    def open_website(self):
+        QDesktopServices.openUrl(QUrl('http://khertan.net/khweeteur'))
+    def open_bugtracker(self):
+        QDesktopServices.openUrl(QUrl('http://khertan.net/khweeteur/bugs'))
+        
             
 class KhweetAction(QDialog):
     def __init__(self,parent = None):
@@ -608,21 +749,25 @@ class KhweetAction(QDialog):
         _layout.setSpacing(6)
         _layout.setMargin(11)
         
+        self.reply = QPushButton('Reply')
+        self.reply.setText(self.tr('&Reply'))
+        _layout.addWidget(self.reply,0,0)
+        
         self.retweet = QPushButton('Retweet')
         self.retweet.setText(self.tr('&Retweet'))
-        _layout.addWidget(self.retweet,0,0)
+        _layout.addWidget(self.retweet,0,1)
 
         self.openurl = QPushButton('Open URL')
         self.openurl.setText(self.tr('&Open URL'))
-        _layout.addWidget(self.openurl,0,1)
+        _layout.addWidget(self.openurl,1,0)
         
         self.follow = QPushButton('Follow')
         self.follow.setText(self.tr('&Follow'))
-        _layout.addWidget(self.follow,1,0)
+        _layout.addWidget(self.follow,0,2)
 
         self.unfollow = QPushButton('Unfollow')
         self.unfollow.setText(self.tr('&Unfollow'))
-        _layout.addWidget(self.unfollow,1,1)        
+        _layout.addWidget(self.unfollow,1,2)        
         
 class KhweeteurPref(QMainWindow):
     def __init__(self, parent=None):
@@ -710,8 +855,8 @@ class KhweeteurPref(QMainWindow):
                             self.settings.setValue('twitter_access_token_secret',QString())
                             self.settings.setValue('twitter_access_token',False)
                         else:
-                            print access_token['oauth_token']
-                            print access_token['oauth_token_secret']
+                            #print access_token['oauth_token']
+                            #print access_token['oauth_token_secret']
                             self.settings.setValue('twitter_access_token_key',QString(access_token['oauth_token']))
                             self.settings.setValue('twitter_access_token_secret',QString(access_token['oauth_token_secret']))
                             self.settings.setValue('twitter_access_token',True)
@@ -772,8 +917,8 @@ class KhweeteurPref(QMainWindow):
                             self.settings.setValue('identica_access_token_secret',QString())
                             self.settings.setValue('identica_access_token',False)
                         else:
-                            print access_token['oauth_token']
-                            print access_token['oauth_token_secret']
+                            #print access_token['oauth_token']
+                            #print access_token['oauth_token_secret']
                             self.settings.setValue('identica_access_token_key',QString(access_token['oauth_token']))
                             self.settings.setValue('identica_access_token_secret',QString(access_token['oauth_token_secret']))
                             self.settings.setValue('identica_access_token',True)
@@ -899,7 +1044,12 @@ class KhweeteurWin(QMainWindow):
     def setupMain(self):
 
         self.tweetsView = KhweetsView(self)
-        self.connect(self.tweetsView,SIGNAL('doubleClicked(const QModelIndex&)'),self.reply)
+        self.tweetsView.custom_delegate.show_screenname = self.settings.value("displayUser").toBool()
+        self.tweetsView.custom_delegate.show_timestamp = self.settings.value("displayTimestamp").toBool()
+        self.tweetsView.custom_delegate.show_avatar = self.settings.value("displayAvatar").toBool()
+
+#        self.connect(self.tweetsView,SIGNAL('doubleClicked(const QModelIndex&)'),self.reply)
+        self.connect(self.tweetsView,SIGNAL('doubleClicked(const QModelIndex&)'),self.tweet_do_ask_action)
         self.tweetsModel = KhweetsModel([],self.search_keyword)
         self.tweetsView.setModel(self.tweetsModel)
         self.setCentralWidget(self.tweetsView)
@@ -907,14 +1057,18 @@ class KhweeteurWin(QMainWindow):
 
         self.toolbar = self.addToolBar('Toolbar')
 
-        self.tb_open = QAction(QIcon.fromTheme("general_add"),'More', self)
-        self.connect(self.tb_open, SIGNAL('triggered()'), self.tweetAction)
-        self.toolbar.addAction(self.tb_open)
+        # self.tb_open = QAction(QIcon.fromTheme("general_add"),'More', self)
+        # self.connect(self.tb_open, SIGNAL('triggered()'), self.tweet_do_ask_action)
+        # self.toolbar.addAction(self.tb_open)
         
         # self.tb_retweet = QAction(QIcon.fromTheme("general_refresh"),'Retweet', self)
         # self.connect(self.tb_retweet, SIGNAL('triggered()'), self.retweet)
         # self.toolbar.addAction(self.tb_retweet)
         
+        self.tb_update = QAction(QIcon.fromTheme("general_refresh"),'Update', self)
+        self.connect(self.tb_update, SIGNAL('triggered()'), self.request_refresh)
+        self.toolbar.addAction(self.tb_update)
+        
         self.tb_text = QLineEdit()
         self.tb_text_replyid = 0
         self.tb_text_replytext = ''
@@ -932,8 +1086,9 @@ class KhweeteurWin(QMainWindow):
         QTimer.singleShot(200, self.timedUnserialize)
 #        self.tweetsModel.unSerialize(self.search_keyword)
 
-    def tweetAction(self):
+    def tweet_do_ask_action(self):
         self.tweetActionDialog = KhweetAction(self)
+        self.connect(self.tweetActionDialog.reply,SIGNAL('clicked()'),self.reply)
         self.connect(self.tweetActionDialog.openurl,SIGNAL('clicked()'),self.open_url)
         self.connect(self.tweetActionDialog.retweet,SIGNAL('clicked()'),self.retweet)
         self.connect(self.tweetActionDialog.follow,SIGNAL('clicked()'),self.follow)
@@ -943,12 +1098,15 @@ class KhweeteurWin(QMainWindow):
     def countChar(self,text):
         self.tb_charCounter.setText(unicode(140-len(text)))
 
-    def reply(self,index):
-        user = self.tweetsModel._items[index.row()][2]
-        self.tb_text_replyid = self.tweetsModel._items[index.row()][1]
-        self.tb_text_replytext = '@'+user+' '
-        self.tb_text.setText('@'+user+' ')
-        print 'DEbug tweet id :',self.tb_text_replyid 
+    def reply(self):
+        self.tweetActionDialog.accept()
+        # user = self.tweetsModel._items[index.row()][2]
+        for index in self.tweetsView.selectedIndexes():
+            user = self.tweetsModel._items[index.row()][2]
+            self.tb_text_replyid = self.tweetsModel._items[index.row()][1]
+            self.tb_text_replytext = '@'+user+' '
+            self.tb_text.setText('@'+user+' ')
+            #print 'DEbug tweet id :',self.tb_text_replyid 
 
     def open_url(self):
         import re
@@ -973,7 +1131,7 @@ class KhweeteurWin(QMainWindow):
                            "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
                            QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
                     user_screenname = self.tweetsModel._items[index.row()][2]
-                    print 'DEBUG Follow:',user_screenname
+                    #print 'DEBUG Follow:',user_screenname
                     try:
                         if self.settings.value("twitter_access_token_key").toString()!='':     
                             api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
@@ -1017,7 +1175,7 @@ class KhweeteurWin(QMainWindow):
                            "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
                            QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
                     user_screenname = self.tweetsModel._items[index.row()][2]
-                    print 'DEBUG Follow:',user_screenname
+                    #print 'DEBUG Follow:',user_screenname
                     try:
                         if self.settings.value("twitter_access_token_key").toString()!='':     
                             api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
@@ -1058,7 +1216,7 @@ class KhweeteurWin(QMainWindow):
                        "Retweet this : %s ?" % self.tweetsModel._items[index.row()][3],
                        QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
                 tweetid = self.tweetsModel._items[index.row()][1]
-                print 'DEBUG Retweet:',tweetid
+                #print 'DEBUG Retweet:',tweetid
                 try:
                     if self.settings.value("twitter_access_token_key").toString()!='':     
                         api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
@@ -1114,65 +1272,18 @@ class KhweeteurWin(QMainWindow):
             self.notifications.connect(self.tweetAction, SIGNAL('warn(PyQt_PyObject)'), self.notifications.warn)
             self.tweetAction.start()
 
-#        try:
-#                status_text = unicode(self.tb_text.text()).encode('UTF-8')
-#                if status_text.startswith(self.tb_text_replytext):
-#                    self.tb_text_replyid = 0
-#                    
-#                if self.settings.value("twitter_access_token_key").toString()!='':     
-#                    api = twitter.Api(
-#                                      username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-#                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-#                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-#                    api.SetUserAgent('Khweeteur/%s' % (__version__))
-#                    if self.settings.value('useSerialization').toBool():
-#                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
-#                    else:
-#                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
-#                    self.notifications.info('Tweet send to Twitter')
-#
-#                if self.settings.value("identica_access_token_key").toString()!='':     
-#                    api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
-#                                      password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-#                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-#                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
-#                    api.SetUserAgent('Khweeteur/%s' % (__version__))
-#                    if self.settings.value('useSerialization').toBool():
-#                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
-#                    else:
-#                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
-#                    self.notifications.info('Tweet send to Identica')
-#                    
-#                self.tb_text.setText('')
-#                self.tb_text_replyid = 0
-#                self.tb_text_replytext = ''
-#        except (twitter.TwitterError,StandardError),e:
-#            import traceback
-#            print traceback.print_exc()
-#            print traceback.print_stack()
-#            if type(e)==twitter.TwitterError:
-#                self.notifications.warn('Send tweet failed : '+(e.message))
-#                print e.message
-#            else:
-#                self.notifications.warn('Send tweet failed : '+str(e))
-#                print e 
-
     def refreshEnded(self):
-#        if self.search_keyword == None:
-#        self.tweetsModel.serialize(self.search_keyword)
         counter=self.tweetsModel.getNew()
         
         if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
             if self.search_keyword:
                 pass
-                #Disable notification for search
-                #self.notifications.notify_search(self.search_keyword,'Khweeteur',self.search_keyword+': '+str(counter)+' new tweet(s)',count=counter)
             else:
                 self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def do_refresh_now(self):
-        print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
+        #print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
         self.worker = KhweeteurWorker(self,search_keyword=self.search_keyword)
         self.connect(self.worker, SIGNAL("newStatuses(PyQt_PyObject)"), self.tweetsModel.addStatuses)
@@ -1196,9 +1307,9 @@ class KhweeteurWin(QMainWindow):
             self.do_refresh_now()
  
     def restartTimer(self):
-        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
-        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
-        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+        self.tweetsView.custom_delegate.show_screenname = self.settings.value("displayUser").toBool()
+        self.tweetsView.custom_delegate.show_timestamp = self.settings.value("displayTimestamp").toBool()
+        self.tweetsView.custom_delegate.show_avatar = self.settings.value("displayAvatar").toBool()
         QObject.emit(self.tweetsModel, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.tweetsModel.createIndex(0,0), self.tweetsModel.createIndex(0,len(self.tweetsModel._items)))
         if (self.settings.value("refreshInterval").toInt()[0]>0):
             self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
@@ -1212,12 +1323,12 @@ class KhweeteurWin(QMainWindow):
 
         fileMenu.addAction(self.tr("&Preferences"), self.do_show_pref,
                 QKeySequence(self.tr("Ctrl+P", "Preferences")))
-        fileMenu.addAction(self.tr("&Update"), self.request_refresh,
-                QKeySequence(self.tr("Ctrl+R", "Update")))
+#        fileMenu.addAction(self.tr("&Update"), self.request_refresh,
+#                QKeySequence(self.tr("Ctrl+R", "Update")))
         fileMenu.addAction(self.tr("&Search"), self.open_search,
                 QKeySequence(self.tr("Ctrl+S", "Search")))
-        fileMenu.addAction(self.tr("&Retweet"), self.retweet,
-                QKeySequence(self.tr("Ctrl+T", "Retweet")))
+#        fileMenu.addAction(self.tr("&Retweet"), self.retweet,
+#                QKeySequence(self.tr("Ctrl+T", "Retweet")))
                 
         if self.search_keyword != None:
             keywords = self.settings.value('savedSearch').toPyObject()
@@ -1355,6 +1466,7 @@ class Khweeteur(QApplication):
         self.crash_report()
         self.win.show()
         sys.exit(self.exec_())
+#        self.exec_()
 
 if __name__ == '__main__':
     Khweeteur()
